export const chatWindowElement = document.querySelector(".chat-window");
export const sendMessageElement = document.querySelector("#send-message");
export const messageTextAreaElement = document.querySelector(".message-textarea");
export const ticketAssignElement = document.querySelector("#ticket-assign");
export const ticketTitleElement = document.querySelector("#ticket-title");
export const managerIdElement = document.querySelector("#manager-id");
export const btnSetUnassignedTicketsElement = document.querySelector("#btn-set-unassigned");
export const btnSetMyTicketsElement = document.querySelector("#btn-set-my");
export const ticketListElement = document.querySelector(".ticket-list");
